@@ -62,7 +62,7 @@
  <tr style="height: 56px;">
   <td style="padding-left: 0.5em;">
    <div id="projectname">IMP Manual
-   &#160;<span id="projectnumber">for IMP version 2.13.0</span>
+   &#160;<span id="projectnumber">for IMP version 2.14.0</span>
    </div>
   </td>
  </tr>
@@ -85,10 +85,10 @@ var searchBox = new SearchBox("searchBox", "search",false,'Search');
           <div class="left">
             <form id="FSearchBox" action="search.php" method="get">
               <img id="MSearchSelect" src="search/mag.png" alt=""/>
-<script language="php">
+<?php
 require_once "search-functions.php";
 main();
-</script>
+?>
 <!-- start footer part -->
 <hr class="footer"/><address class="footer"><small>
 <script type='text/javascript'>
